.. _recipe_asr.bandstructure:

asr.bandstructure
=================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.bandstructure`-recipe.
This recipe is comprised of 2 steps, namely:

  - :py:func:`asr.bandstructure.calculate`
  - :py:func:`asr.bandstructure.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.bandstructure

or as a python module

.. code-block:: console

   $ python -m asr.bandstructure

Detailed description
--------------------
Electronic band structures.

Steps
-----


asr.bandstructure@calculate
^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.bandstructure.calculate
   

asr.bandstructure
^^^^^^^^^^^^^^^^^
.. autofunction:: asr.bandstructure.main
   